﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Editors;
using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 볼륨 시리즈
        /// </summary>
        private Volume volume;

        /// <summary>
        /// PVO 함수
        /// </summary>
        private PVOFunction pvoFunction;

        /// <summary>
        /// 패스트 라인 시리즈
        /// </summary>
        private FastLine fastLine;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 볼륨 시리즈를 생성한다.

            this.volume = new Volume();

            this.volume.Title       = "volume";
            this.volume.Brush.Color = Color.FromArgb(200, 230, 90);
            this.volume.Color       = Color.FromArgb(200, 230, 90);

            #endregion
            #region PVO 함수를 생성한다.

            this.pvoFunction = new PVOFunction();

            this.pvoFunction.Period = 12d;

            #endregion
            #region 패스트 라인을 생성한다.

            this.fastLine = new FastLine();

            this.fastLine.Title      = "fastLine";
            this.fastLine.Color      = Color.FromArgb(90, 150, 220);
            this.fastLine.DataSource = this.volume;
            this.fastLine.Function   = this.pvoFunction;

            #endregion
            #region 티차트를 설정한다.

            this.tChart.Axes.Left.Grid.Color     = Color.FromArgb(130, 130, 130);
            this.tChart.Axes.Bottom.Grid.Color   = Color.FromArgb(130, 130, 130);
            this.tChart.Axes.Bottom.Grid.Visible = true;

            this.tChart.Series.Add(this.volume);
            this.tChart.Series.Add(this.fastLine);

            #endregion

            this.volume.FillSampleValues();

            this.editButton.Click += editButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 편집 버튼 클릭시 처리하기 - editButton_Click(sender, e)

        /// <summary>
        /// 편집 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void editButton_Click(object sender, EventArgs e)
        {
            PVOFunctionEditor editor = new PVOFunctionEditor(this.fastLine.Function);

            editor.StartPosition = FormStartPosition.CenterParent;

            editor.ShowDialog();
        }

        #endregion
    }
}